@@ -1,4 +1,5 @@
-# ruff: noqa: D100, D101, D102, D103, D104, D105, D107
+"""Redux autorun module."""
+
 from __future__ import annotations
 
 import asyncio
@@ -17,11 +18,11 @@ from typing import (
 
 from redux.basic_types import (
     Action,
-    AutorunArgs,
+    Args,
     AutorunOptions,
-    AutorunOriginalReturnType,
     ComparatorOutput,
     Event,
+    ReturnType,
     SelectorOutput,
     State,
 )
@@ -36,18 +37,24 @@ T = TypeVar('T')
 
 
 class AwaitableWrapper(Generic[T]):
+    """A wrapper for a coroutine to track if it has been awaited."""
+
     def __init__(self, coro: Coroutine[None, None, T]) -> None:
+        """Initialize the AwaitableWrapper with a coroutine."""
         self.coro = coro
         self.awaited = False
 
     def __await__(self) -> Generator[None, None, T]:
+        """Await the coroutine and set the awaited flag to True."""
         self.awaited = True
         return self.coro.__await__()
 
     def close(self) -> None:
+        """Close the coroutine if it has not been awaited."""
         self.coro.close()
 
     def __repr__(self) -> str:
+        """Return a string representation of the AwaitableWrapper."""
         return f'AwaitableWrapper({self.coro}, awaited={self.awaited})'
 
 
@@ -58,10 +65,12 @@ class Autorun(
         Event,
         SelectorOutput,
         ComparatorOutput,
-        AutorunOriginalReturnType,
-        AutorunArgs,
+        Args,
+        ReturnType,
     ],
 ):
+    """Run a wrapped function in response to specific state changes in the store."""
+
     def __init__(
         self: Autorun,
         *,
@@ -69,12 +78,16 @@ class Autorun(
         selector: Callable[[State], SelectorOutput],
         comparator: Callable[[State], Any] | None,
         func: Callable[
-            Concatenate[SelectorOutput, AutorunArgs],
-            AutorunOriginalReturnType,
+            Concatenate[SelectorOutput, Args],
+            ReturnType,
         ],
-        options: AutorunOptions[AutorunOriginalReturnType],
+        options: AutorunOptions[ReturnType],
     ) -> None:
-        self.__name__ = func.__name__
+        """Initialize the Autorun instance."""
+        if hasattr(func, '__name__'):
+            self.__name__ = f'Autorun:{func.__name__}'
+        else:
+            self.__name__ = f'Autorun:{func}'
         self._store = store
         self._selector = selector
         self._comparator = comparator
@@ -102,30 +115,47 @@ class Autorun(
 
         self._last_selector_result: SelectorOutput | None = None
         self._last_comparator_result: ComparatorOutput = cast(
-            ComparatorOutput,
+            'ComparatorOutput',
             object(),
         )
         if iscoroutinefunction(func):
             self._latest_value = Future()
             self._latest_value.set_result(options.default_value)
         else:
-            self._latest_value: AutorunOriginalReturnType = options.default_value
+            self._latest_value: ReturnType = options.default_value
         self._subscriptions: set[
-            Callable[[AutorunOriginalReturnType], Any]
-            | weakref.ref[Callable[[AutorunOriginalReturnType], Any]]
+            Callable[[ReturnType], Any] | weakref.ref[Callable[[ReturnType], Any]]
         ] = set()
 
         if self._check(store._state) and self._options.initial_call:  # noqa: SLF001
             self._call()
 
         if self._options.reactive:
-            self._unsubscribe = store.subscribe(
-                lambda state: self._call() if self._check(state) else None,
-            )
+            self._unsubscribe = store._subscribe(self._react)  # noqa: SLF001
         else:
             self._unsubscribe = None
 
-    def unsubscribe(self: Autorun, _: weakref.ref | None = None) -> None:
+    def _react(
+        self: Autorun,
+        state: State,
+    ) -> None:
+        """React to state changes in the store."""
+        if self._options.reactive and self._check(state):
+            self._call()
+
+    def unsubscribe(
+        self: Autorun[
+            State,
+            Action,
+            Event,
+            SelectorOutput,
+            ComparatorOutput,
+            Args,
+            ReturnType,
+        ],
+        _: weakref.ref | None = None,
+    ) -> None:
+        """Unsubscribe the autorun from the store and clean up resources."""
         if self._unsubscribe:
             self._unsubscribe()
             self._unsubscribe = None
@@ -137,10 +167,11 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
     ) -> None:
+        """Inform all subscribers about the latest value."""
         for subscriber_ in self._subscriptions.copy():
             if isinstance(subscriber_, weakref.ref):
                 subscriber = subscriber_()
@@ -158,8 +189,8 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
         task: Task,
         *,
@@ -179,8 +210,8 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
         state: State | None,
     ) -> bool:
@@ -191,7 +222,7 @@ class Autorun(
         except AttributeError:
             return False
         if self._comparator is None:
-            comparator_result = cast(ComparatorOutput, selector_result)
+            comparator_result = cast('ComparatorOutput', selector_result)
         else:
             try:
                 comparator_result = self._comparator(state)
@@ -211,16 +242,16 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
-        *args: AutorunArgs.args,
-        **kwargs: AutorunArgs.kwargs,
+        *args: Args.args,
+        **kwargs: Args.kwargs,
     ) -> None:
         self._should_be_called = False
         func = self._func() if isinstance(self._func, weakref.ref) else self._func
         if func and self._last_selector_result is not None:
-            value: AutorunOriginalReturnType = func(
+            value: ReturnType = func(
                 self._last_selector_result,
                 *args,
                 **kwargs,
@@ -229,7 +260,7 @@ class Autorun(
             if iscoroutine(value) and create_task:
                 if self._options.auto_await:
                     future = Future()
-                    self._latest_value = cast(AutorunOriginalReturnType, future)
+                    self._latest_value = cast('ReturnType', future)
                     create_task(
                         value,
                         callback=functools.partial(
@@ -245,7 +276,7 @@ class Autorun(
                     ):
                         self._latest_value.close()
                     self._latest_value = cast(
-                        AutorunOriginalReturnType,
+                        'ReturnType',
                         AwaitableWrapper(value),
                     )
             else:
@@ -259,16 +290,18 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
-        *args: AutorunArgs.args,
-        **kwargs: AutorunArgs.kwargs,
-    ) -> AutorunOriginalReturnType:
+        *args: Args.args,
+        **kwargs: Args.kwargs,
+    ) -> ReturnType:
+        """Call the wrapped function with the current state of the store."""
         state = self._store._state  # noqa: SLF001
-        if self._check(state) or self._should_be_called or args or kwargs:
+        self._check(state)
+        if self._should_be_called or args or kwargs or not self._options.memoization:
             self._call(*args, **kwargs)
-        return cast(AutorunOriginalReturnType, self._latest_value)
+        return cast('ReturnType', self._latest_value)
 
     def __repr__(
         self: Autorun[
@@ -277,10 +310,11 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
     ) -> str:
+        """Return a string representation of the Autorun instance."""
         return (
             super().__repr__()
             + f'(func: {self._func}, last_value: {self._latest_value})'
@@ -294,11 +328,12 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
-    ) -> AutorunOriginalReturnType:
-        return cast(AutorunOriginalReturnType, self._latest_value)
+    ) -> ReturnType:
+        """Get the latest value of the autorun function."""
+        return cast('ReturnType', self._latest_value)
 
     def subscribe(
         self: Autorun[
@@ -307,14 +342,15 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
-        callback: Callable[[AutorunOriginalReturnType], Any],
+        callback: Callable[[ReturnType], Any],
         *,
         initial_run: bool | None = None,
         keep_ref: bool | None = None,
     ) -> Callable[[], None]:
+        """Subscribe to the autorun to be notified of changes in the state."""
         if initial_run is None:
             initial_run = self._options.subscribers_initial_run
         if keep_ref is None:
@@ -343,8 +379,9 @@ class Autorun(
             Event,
             SelectorOutput,
             ComparatorOutput,
-            AutorunOriginalReturnType,
-            AutorunArgs,
+            Args,
+            ReturnType,
         ],
     ) -> inspect.Signature:
+        """Get the signature of the wrapped function."""
         return self._signature
